import type { Extends, Plugin } from '@aet/eslint-define-config';
import * as fs from 'node:fs';
import { resolve } from 'node:path';

export function checkEnv() {
  const rootDir = process.cwd();
  const plugins: Plugin[] = [];
  const extend: Extends[] = [];

  const pkgJsonPath = resolve(rootDir, 'package.json');
  const pkgJson = fs.existsSync(pkgJsonPath)
    ? JSON.parse(fs.readFileSync(pkgJsonPath, 'utf-8'))
    : {};

  const deps = Object.keys({
    ...pkgJson.dependencies,
    ...pkgJson.devDependencies,
    ...pkgJson.peerDependencies,
  });

  const hasReact = deps.includes('react');
  if (hasReact) {
    plugins.push('react-hooks');
  }
  if (deps.includes('@vitejs/plugin-react')) {
    plugins.push('react-refresh');
  }

  if (deps.includes('tailwindcss') && deps.includes('eslint-plugin-tailwindcss')) {
    plugins.push('tailwindcss');
  }

  if (deps.includes('storybook') && deps.includes('eslint-plugin-storybook')) {
    extend.push('plugin:storybook/recommended');
  }

  if (deps.includes('@tanstack/react-query')) {
    extend.push('plugin:@tanstack/eslint-plugin-query/recommended');
  }

  return {
    react: hasReact,
    plugins,
    extends: extend,
  };
}
